@@ -19,7 +19,7 @@ import urllib.parse
 
 
 from flask import Blueprint, abort, jsonify, request
-from flask_restplus import Api, Resource, inputs, reqparse, fields
+from flask_restx import Api, Resource, inputs, reqparse, fields
 from flask_security import auth_required, current_user, http_auth_required, permissions_accepted, permissions_required
 from flask_security.utils import hash_password
 import marshmallow
@@ -35,21 +35,14 @@ from ..fields import ObjectUrl, SubUrl
 from ..util.helpers import get_object_from_arg
 
 db = models.db
-
 blueprint = Blueprint('api_v1', __name__)
 
-authorization = {
-    'basic_auth': {'type': 'basic'}
-}
-
 api = RegisteredApi(
     blueprint,
     version='1.0',
     title='Population Imaging Database REST API',
     description='The Population Imaging Database is for storing the results of population imaging studies.',
-    default_mediatype='application/json',
-    authorization=authorization,
-    security='basic_auth'
+    default_mediatype='application/json'
 )
 
 
@@ -132,7 +125,7 @@ class XnatResourceSchema(marshmallow.Schema):
 class ExperimentSchema(marshmallow.Schema):
     experiment_id = marshmallow.fields.Int()
     subject_id = marshmallow.fields.Int()
-    label =  marshmallow.fields.String(validate=lambda s: len(s) < 255)
+    label = marshmallow.fields.String(validate=lambda s: len(s) < 255)
     date = marshmallow.fields.DateTime()
 
     xnat_resources = marshmallow.fields.Nested(XnatResourceSchema(many=True))
@@ -264,6 +257,7 @@ post_experiment = api.model('post-experiment', {
 
 @api.route('/experiment/<string:experiment_id>', endpoint='experiment')
 class ExperimentGetDeleteEndpoint(Resource):
+    @http_auth_required
     @api.response(200, 'OK')
     def get(self, experiment_id):
         schema = ExperimentSchema()
@@ -286,6 +280,8 @@ class ExperimentGetDeleteEndpoint(Resource):
 
         return {}, 200
 
+    @http_auth_required
+    @permissions_accepted('finding_delete')
     @api.response(200, 'OK')
     def delete(self, experiment_id):
         session = db.session
@@ -303,6 +299,8 @@ class ExperimentGetDeleteEndpoint(Resource):
 
 @api.route('/experiment/bysubject/<string:subject_id>/<string:date>')
 class ExperimentPutEndpoint(Resource):
+    @http_auth_required
+    @permissions_accepted('finding_update')
     @api.response(201, 'Experiment successfully created.')
     @api.expect(post_experiment, validate=True)
     def put(self, subject_id, date):
@@ -343,6 +341,7 @@ put_subject = api.model('put-subject', {
 
 @api.route('/subject/bystudyid/<string:study_id>')
 class SubjectGetDeleteEndpointByStudyId(Resource):
+    @http_auth_required
     @api.response(200, 'OK')
     def get(self, study_id):
         schema = SubjectSchema()
@@ -365,6 +364,8 @@ class SubjectGetDeleteEndpointByStudyId(Resource):
 
         return {}, 200
 
+    @http_auth_required
+    @permissions_accepted('finding_delete')
     @api.response(200, 'OK')
     def delete(self, study_id):
         session = db.session
@@ -381,6 +382,7 @@ class SubjectGetDeleteEndpointByStudyId(Resource):
 @api.route('/subject/<string:subject_id>')
 class SubjectGetDeleteEndpoint(Resource):
     @api.response(200, 'OK')
+    @http_auth_required
     def get(self, subject_id):
         schema = SubjectSchema()
 
@@ -402,6 +404,8 @@ class SubjectGetDeleteEndpoint(Resource):
 
         return {}, 200
 
+    @http_auth_required
+    @permissions_accepted('finding_delete')
     @api.response(200, 'OK')
     def delete(self, subject_id):
         session = db.session
@@ -417,6 +421,8 @@ class SubjectGetDeleteEndpoint(Resource):
 
 @api.route('/subject/bystudyid/<string:study_id>')
 class SubjectPutEndpoint(Resource):
+    @http_auth_required
+    @permissions_accepted('finding_update')
     @api.response(201, 'Subject successfully created.')
     @api.expect(put_subject, validate=True)
     def put(self, study_id):
@@ -456,6 +462,8 @@ post_finding = api.model('post-finding', {
 
 @api.route('/finding/byexperimentidandtemplateproperty/<string:experiment_id>/<string:template_name>')
 class DeleteByExerimentIdEndpoint(Resource):
+    @http_auth_required
+    @permissions_accepted('finding_delete')
     @api.response(200, 'OK')
     def delete(self, experiment_id, template_name):
         session = db.session
@@ -487,6 +495,7 @@ class DeleteByExerimentIdEndpoint(Resource):
 
 @api.route('/finding/<string:finding_id>')
 class FindingGetEndpoint(Resource):
+    @http_auth_required
     @api.response(200, 'OK')
     def get(self, finding_id):
         schema = FindingSchema()
@@ -509,6 +518,8 @@ class FindingGetEndpoint(Resource):
 
         return {}, 200
 
+    @http_auth_required
+    @permissions_accepted('finding_delete')
     @api.response(200, 'OK')
     def delete(self, finding_id):
         session = db.session
@@ -526,6 +537,8 @@ class FindingGetEndpoint(Resource):
 
 @api.route('/finding')
 class FindingPostEndpoint(Resource):
+    @http_auth_required
+    @permissions_accepted('finding_update')
     @api.response(201, 'Finding successfully created.')
     @api.expect(post_finding, validate=True)
     def post(self):
@@ -560,6 +573,7 @@ post_label = api.model('post-label', {
 
 @api.route('/label/<string:label_id>')
 class LabelGetEndpoint(Resource):
+    @http_auth_required
     @api.response(200, 'OK')
     def get(self, label_id):
         schema = LabelSchema()
@@ -582,6 +596,8 @@ class LabelGetEndpoint(Resource):
 
         return {}, 200
 
+    @http_auth_required
+    @permissions_accepted('finding_delete')
     @api.response(200, 'OK')
     def delete(self, label_id):
         session = db.session
@@ -601,6 +617,8 @@ class LabelGetEndpoint(Resource):
 class LabelPutEndpoint(Resource):
     @api.response(201, 'Label successfully created.')
     #@api.expect(post_label, validate=True)
+    @http_auth_required
+    @permissions_accepted('finding_update')
     def put(self, label_text):
         schema = LabelSchema()
 
@@ -630,6 +648,8 @@ class LabelPutEndpoint(Resource):
 class LabelGetEndpoint(Resource):
     @api.response(201, 'Label successfully created.')
     @api.expect(post_label, validate=True)
+    @http_auth_required
+    @permissions_accepted('finding_update')
     def post(self):
         schema = LabelSchema()
 
@@ -654,6 +674,7 @@ class LabelGetEndpoint(Resource):
 
         return result, 201
 
+    @http_auth_required
     @api.response(200, 'OK')
     def get(self):
         schema = LabelSchema(many=True)
@@ -756,6 +777,7 @@ put_property = api.model('put-property', {
 
 @api.route('/property/<string:property_id>')
 class LabelGetEndpoint(Resource):
+    @http_auth_required
     @api.response(200, 'OK')
     def get(self, property_id):
         schema = PropertySchema()
@@ -776,6 +798,8 @@ class LabelGetEndpoint(Resource):
 
         return {}, 200
 
+    @http_auth_required
+    @permissions_accepted('finding_delete')
     @api.response(200, 'OK')
     def delete(self, property_id):
         session = db.session
@@ -794,6 +818,8 @@ class LabelGetEndpoint(Resource):
 
 @api.route('/property/byfindingid/<string:finding_id>/<string:property_label>')
 class FindingPutEndpoint(Resource):
+    @http_auth_required
+    @permissions_accepted('finding_update')
     @api.response(201, 'Property successfully created.')
     @api.expect(put_property, validate=True)
     def put(self, finding_id, property_label):
